@@ -7,9 +7,8 @@ use crate::models::common::Location;
 use crate::models::problem::*;
 use crate::models::solution::{Registry, Route};
 use crate::models::{Problem, Solution};
-use crate::solver::population::create_elitism_population;
-use crate::solver::RefinementContext;
-use crate::utils::Environment;
+use crate::solver::{create_elitism_population, RefinementContext};
+use rosomaxa::prelude::Environment;
 use std::sync::Arc;
 
 mod mutation;
@@ -21,7 +20,6 @@ pub fn create_default_refinement_ctx(problem: Arc<Problem>) -> RefinementContext
         problem.clone(),
         create_elitism_population(problem.objective.clone(), environment.clone()),
         environment,
-        None,
     )
 }
 
@@ -105,7 +103,7 @@ pub fn generate_matrix_routes(
         constraint: Arc::new(create_constraint_pipeline_with_transport()),
         activity: Arc::new(TestActivityCost::default()),
         transport,
-        objective: Arc::new(ObjectiveCost::default()),
+        objective: Arc::new(ProblemObjective::default()),
         extras: Arc::new(Default::default()),
     };
 
