@@ -6,7 +6,7 @@ use crate::models::common::*;
 use crate::models::problem::*;
 use crate::models::solution::Place;
 use crate::models::{Lock, LockDetail, LockOrder, LockPosition, Problem};
-use crate::utils::Environment;
+use rosomaxa::prelude::Environment;
 
 type JobData = (Option<Location>, (f64, f64), Duration, i32);
 type VehicleData = ((Location, Option<f64>, Option<f64>), Option<(Location, Option<f64>, Option<f64>)>);
@@ -96,7 +96,7 @@ fn create_test_problem(
         constraint: Arc::new(constraint),
         activity,
         transport,
-        objective: Arc::new(ObjectiveCost::default()),
+        objective: Arc::new(ProblemObjective::default()),
         extras: Arc::new(Default::default()),
     }
 }
